//
// asio.hpp
// ~~~~~~~~
//
// Copyright (c) 2003-2015 Christopher M. Kohlhoff (chris at kohlhoff dot com)
//
// Distributed under the Boost Software License, Version 1.0. (See accompanying
// file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
//

#ifndef ASIO_HPP
#define ASIO_HPP

#if defined(_MSC_VER) && (_MSC_VER >= 1200)
# pragma once
#endif // defined(_MSC_VER) && (_MSC_VER >= 1200)

#include "asio/include/asio/async_result.hpp"
#include "asio/include/asio/basic_datagram_socket.hpp"
#include "asio/include/asio/basic_deadline_timer.hpp"
#include "asio/include/asio/basic_io_object.hpp"
#include "asio/include/asio/basic_raw_socket.hpp"
#include "asio/include/asio/basic_seq_packet_socket.hpp"
#include "asio/include/asio/basic_serial_port.hpp"
#include "asio/include/asio/basic_signal_set.hpp"
#include "asio/include/asio/basic_socket_acceptor.hpp"
#include "asio/include/asio/basic_socket_iostream.hpp"
#include "asio/include/asio/basic_socket_streambuf.hpp"
#include "asio/include/asio/basic_stream_socket.hpp"
#include "asio/include/asio/basic_streambuf.hpp"
#include "asio/include/asio/basic_waitable_timer.hpp"
#include "asio/include/asio/buffer.hpp"
#include "asio/include/asio/buffered_read_stream_fwd.hpp"
#include "asio/include/asio/buffered_read_stream.hpp"
#include "asio/include/asio/buffered_stream_fwd.hpp"
#include "asio/include/asio/buffered_stream.hpp"
#include "asio/include/asio/buffered_write_stream_fwd.hpp"
#include "asio/include/asio/buffered_write_stream.hpp"
#include "asio/include/asio/buffers_iterator.hpp"
#include "asio/include/asio/completion_condition.hpp"
#include "asio/include/asio/connect.hpp"
#include "asio/include/asio/coroutine.hpp"
#include "asio/include/asio/datagram_socket_service.hpp"
#include "asio/include/asio/deadline_timer_service.hpp"
#include "asio/include/asio/deadline_timer.hpp"
#include "asio/include/asio/error.hpp"
#include "asio/include/asio/error_code.hpp"
#include "asio/include/asio/generic/basic_endpoint.hpp"
#include "asio/include/asio/generic/datagram_protocol.hpp"
#include "asio/include/asio/generic/raw_protocol.hpp"
#include "asio/include/asio/generic/seq_packet_protocol.hpp"
#include "asio/include/asio/generic/stream_protocol.hpp"
#include "asio/include/asio/handler_alloc_hook.hpp"
#include "asio/include/asio/handler_continuation_hook.hpp"
#include "asio/include/asio/handler_invoke_hook.hpp"
#include "asio/include/asio/handler_type.hpp"
#include "asio/include/asio/io_service.hpp"
#include "asio/include/asio/ip/address.hpp"
#include "asio/include/asio/ip/address_v4.hpp"
#include "asio/include/asio/ip/address_v6.hpp"
#include "asio/include/asio/ip/basic_endpoint.hpp"
#include "asio/include/asio/ip/basic_resolver.hpp"
#include "asio/include/asio/ip/basic_resolver_entry.hpp"
#include "asio/include/asio/ip/basic_resolver_iterator.hpp"
#include "asio/include/asio/ip/basic_resolver_query.hpp"
#include "asio/include/asio/ip/host_name.hpp"
#include "asio/include/asio/ip/icmp.hpp"
#include "asio/include/asio/ip/multicast.hpp"
#include "asio/include/asio/ip/resolver_query_base.hpp"
#include "asio/include/asio/ip/resolver_service.hpp"
#include "asio/include/asio/ip/tcp.hpp"
#include "asio/include/asio/ip/udp.hpp"
#include "asio/include/asio/ip/unicast.hpp"
#include "asio/include/asio/ip/v6_only.hpp"
#include "asio/include/asio/is_read_buffered.hpp"
#include "asio/include/asio/is_write_buffered.hpp"
#include "asio/include/asio/local/basic_endpoint.hpp"
#include "asio/include/asio/local/connect_pair.hpp"
#include "asio/include/asio/local/datagram_protocol.hpp"
#include "asio/include/asio/local/stream_protocol.hpp"
#include "asio/include/asio/placeholders.hpp"
#include "asio/include/asio/posix/basic_descriptor.hpp"
#include "asio/include/asio/posix/basic_stream_descriptor.hpp"
#include "asio/include/asio/posix/descriptor_base.hpp"
#include "asio/include/asio/posix/stream_descriptor.hpp"
#include "asio/include/asio/posix/stream_descriptor_service.hpp"
#include "asio/include/asio/raw_socket_service.hpp"
#include "asio/include/asio/read.hpp"
#include "asio/include/asio/read_at.hpp"
#include "asio/include/asio/read_until.hpp"
#include "asio/include/asio/seq_packet_socket_service.hpp"
#include "asio/include/asio/serial_port.hpp"
#include "asio/include/asio/serial_port_base.hpp"
#include "asio/include/asio/serial_port_service.hpp"
#include "asio/include/asio/signal_set.hpp"
#include "asio/include/asio/signal_set_service.hpp"
#include "asio/include/asio/socket_acceptor_service.hpp"
#include "asio/include/asio/socket_base.hpp"
#include "asio/include/asio/strand.hpp"
#include "asio/include/asio/stream_socket_service.hpp"
#include "asio/include/asio/streambuf.hpp"
#include "asio/include/asio/system_error.hpp"
#include "asio/include/asio/thread.hpp"
#include "asio/include/asio/time_traits.hpp"
#include "asio/include/asio/version.hpp"
#include "asio/include/asio/wait_traits.hpp"
#include "asio/include/asio/waitable_timer_service.hpp"
#include "asio/include/asio/windows/basic_handle.hpp"
#include "asio/include/asio/windows/basic_object_handle.hpp"
#include "asio/include/asio/windows/basic_random_access_handle.hpp"
#include "asio/include/asio/windows/basic_stream_handle.hpp"
#include "asio/include/asio/windows/object_handle.hpp"
#include "asio/include/asio/windows/object_handle_service.hpp"
#include "asio/include/asio/windows/overlapped_ptr.hpp"
#include "asio/include/asio/windows/random_access_handle.hpp"
#include "asio/include/asio/windows/random_access_handle_service.hpp"
#include "asio/include/asio/windows/stream_handle.hpp"
#include "asio/include/asio/windows/stream_handle_service.hpp"
#include "asio/include/asio/write.hpp"
#include "asio/include/asio/write_at.hpp"

#endif // ASIO_HPP
